==> cirq-0.3.1.27-py2-none-any.whl: cirq/google/__init__.py <==
# coding=utf-8
# Copyright 2018 The Cirq Developers
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import
from cirq.google.convert_to_xmon_gates import (
    ConvertToXmonGates,
)
from cirq.google.decompositions import (
    controlled_op_to_native_gates,
    is_negligible_turn,
    single_qubit_matrix_to_native_gates,
    single_qubit_op_to_framed_phase_form,
    two_qubit_matrix_to_native_gates,
)
from cirq.google.eject_full_w import (
    EjectFullW,
)
from cirq.google.eject_z import (
    EjectZ,
)
from cirq.google.known_devices import (
    Bristlecone,
    Foxtail,
)
from cirq.google.merge_interactions import (
    MergeInteractions,
)
from cirq.google.merge_rotations import (
    MergeRotations,
)
from cirq.google.xmon_device import (
    XmonDevice,
)
from cirq.google.xmon_gate_extensions import (
    xmon_gate_ext,
)
from cirq.google.optimize import (
    optimized_for_xmon,
)
from cirq.google.xmon_gates import (
    Exp11Gate,
    ExpWGate,
    ExpZGate,
    XmonGate,
    XmonMeasurementGate,
)
from cirq.google.sim import (
    XmonOptions,
    XmonSimulator,
    XmonStepResult,
    XmonSimulateTrialResult,
)
from cirq.google.engine import (
    engine_from_environment,
    Engine,
    JobConfig,
)

==> cirq-0.4.0.dev4220181119182308-py2-none-any.whl: cirq/google/__init__.py <==
# coding=utf-8
# Copyright 2018 The Cirq Developers
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from __future__ import absolute_import
from cirq.google.convert_to_xmon_gates import (
    ConvertToXmonGates,
)
from cirq.google.decompositions import (
    controlled_op_to_native_gates,
    single_qubit_matrix_to_native_gates,
)
from cirq.google.known_devices import (
    Bristlecone,
    Foxtail,
)
from cirq.google.merge_rotations import (
    MergeRotations,
)
from cirq.google.xmon_device import (
    XmonDevice,
)
from cirq.google.optimize import (
    optimized_for_xmon,
)
from cirq.google.sim import (
    XmonOptions,
    XmonSimulator,
    XmonStepResult,
)
from cirq.google.engine import (
    engine_from_environment,
    Engine,
    JobConfig,
)
from cirq.google.programs import (
    gate_to_proto_dict,
    is_native_xmon_op,
    schedule_from_proto_dicts,
    schedule_to_proto_dicts,
    pack_results,
    unpack_results,
    xmon_op_from_proto_dict,
)

from cirq.google.line import (
    AnnealSequenceSearchStrategy,
    GreedySequenceSearchStrategy,
    LinePlacementStrategy,
    line_on_device,
)
